from collections import OrderedDict
from django.conf import settings
from django.urls import reverse


def admin_theme(request):
    context = {}
    if request.path.startswith(reverse('admin:index')):
        if getattr(settings, 'ADMIN_COLORS', None):
            themes = OrderedDict([
                (x, y if isinstance(y, (list, tuple)) else (y, ))
                for x, y in settings.ADMIN_COLORS
            ])
            context.update({
                'themes': themes,
                'theme': themes.get(
                    request.COOKIES['theme']
                ) if 'theme' in request.COOKIES else 'Default'
            })
    return context



from admincolors.context_processors import admin_theme
from collections import OrderedDict
from django.test import RequestFactory
from django.test import TestCase


class TestContextProcessors(TestCase):

    def setUp(self):
        self.request = RequestFactory().get('/admin/')
        self.request.COOKIES['theme'] = 'Test'

    def test_admin_theme(self):
        context = admin_theme(self.request)
        self.assertEqual(context, {
            'theme': ('test.css', ), 'themes': OrderedDict([
                ('Test', ('test.css', ))
            ])
        })
